"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_record_1 = require("../records/ad.record");
const db_1 = require("../utils/db");
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    db_1.pool.end();
}));
test("AdRecord.findOne returns data from database for one entry", () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.findOne("117608e2-65cf-483d-ae0d-a6b731932041");
    expect(ad).toBeDefined();
    expect(ad.id).toBe("117608e2-65cf-483d-ae0d-a6b731932041");
    expect(ad.name).toBe("Mariańskie Porzecze");
}));
test("AdRecord.findOne returns null from database for unexisting entry.", () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.findOne("gsgdgddgdg");
    expect(ad).toBeNull();
}));
test("AdRecord.findAll returns all ads table entries", () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll("");
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
}));
test("AdRecord.findAll searches for specified query and return empty array if not found", () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.findAll("fffsfsfwweewwe");
    expect(ad).toEqual([]);
}));
test("AdRecord.findAll searches for specified query and returns array of results", () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.findAll("Mariańskie Porzecze");
    expect(ad).not.toEqual([]);
    expect(ad[0].id).toBeDefined();
}));
test("AdRecord.findAll returns only id, lat and lon properties", () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.findAll("Mariańskie Porzecze");
    expect(ad[0].id).toBeDefined();
    expect(ad[0].lat).toBeDefined();
    expect(ad[0].lon).toBeDefined();
}));
test("New record is made and id is generated", () => __awaiter(void 0, void 0, void 0, function* () {
    const obj = {
        name: "Drewno z Radości",
        description: "Dupa",
        price: 43,
        url: "http://olx.pl/dfdgddre54bch5",
        lon: 52.1801894,
        lat: 21.1914945,
    };
    const record = yield new ad_record_1.AdRecord(obj);
    yield record.insertAd();
    expect(typeof record.id).toBe("string");
}));
test("New record is inserts to database", () => __awaiter(void 0, void 0, void 0, function* () {
    const obj = {
        name: "Drewno z Radości",
        description: "Dupa",
        price: 43,
        url: "http://olx.pl/dfdgddre54bch5",
        lon: 52.1801894,
        lat: 21.1914945,
    };
    const record = yield new ad_record_1.AdRecord(obj);
    yield record.insertAd();
    const foundAd = yield ad_record_1.AdRecord.findOne(record.id);
    expect(foundAd).toBeDefined();
}));
//# sourceMappingURL=ads.test.js.map